==> aws-android-sdk-cognitoidentityprovider-2.2.16-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/DescribeUserPoolResult.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cognitoidentityprovider.model;

import java.io.Serializable;

/**
 * <p>
 * Represents the response to describe the user pool.
 * </p>
 */
public class DescribeUserPoolResult implements Serializable {

    /**
     * The container of metadata returned by the server to describe the pool.
     */
    private UserPoolType userPool;

    /**
     * The container of metadata returned by the server to describe the pool.
     *
     * @return The container of metadata returned by the server to describe the pool.
     */
    public UserPoolType getUserPool() {
        return userPool;
    }
    
    /**
     * The container of metadata returned by the server to describe the pool.
     *
     * @param userPool The container of metadata returned by the server to describe the pool.
     */
    public void setUserPool(UserPoolType userPool) {
        this.userPool = userPool;
    }
    
    /**
     * The container of metadata returned by the server to describe the pool.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param userPool The container of metadata returned by the server to describe the pool.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public DescribeUserPoolResult withUserPool(UserPoolType userPool) {
        this.userPool = userPool;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getUserPool() != null) sb.append("UserPool: " + getUserPool() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getUserPool() == null) ? 0 : getUserPool().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof DescribeUserPoolResult == false) return false;
        DescribeUserPoolResult other = (DescribeUserPoolResult)obj;
        
        if (other.getUserPool() == null ^ this.getUserPool() == null) return false;
        if (other.getUserPool() != null && other.getUserPool().equals(this.getUserPool()) == false) return false; 
        return true;
    }
    
}

==> aws-android-sdk-cognitoidentityprovider-2.14.2-sources.jar: com/amazonaws/services/cognitoidentityprovider/model/DescribeUserPoolResult.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitoidentityprovider.model;

import java.io.Serializable;

/**
 * <p>
 * Represents the response to describe the user pool.
 * </p>
 */
public class DescribeUserPoolResult implements Serializable {
    /**
     * <p>
     * The container of metadata returned by the server to describe the pool.
     * </p>
     */
    private UserPoolType userPool;

    /**
     * <p>
     * The container of metadata returned by the server to describe the pool.
     * </p>
     *
     * @return <p>
     *         The container of metadata returned by the server to describe the
     *         pool.
     *         </p>
     */
    public UserPoolType getUserPool() {
        return userPool;
    }

    /**
     * <p>
     * The container of metadata returned by the server to describe the pool.
     * </p>
     *
     * @param userPool <p>
     *            The container of metadata returned by the server to describe
     *            the pool.
     *            </p>
     */
    public void setUserPool(UserPoolType userPool) {
        this.userPool = userPool;
    }

    /**
     * <p>
     * The container of metadata returned by the server to describe the pool.
     * </p>
     * <p>
     * Returns a reference to this object so that method calls can be chained
     * together.
     *
     * @param userPool <p>
     *            The container of metadata returned by the server to describe
     *            the pool.
     *            </p>
     * @return A reference to this updated object so that method calls can be
     *         chained together.
     */
    public DescribeUserPoolResult withUserPool(UserPoolType userPool) {
        this.userPool = userPool;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getUserPool() != null)
            sb.append("UserPool: " + getUserPool());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode + ((getUserPool() == null) ? 0 : getUserPool().hashCode());
        return hashCode;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof DescribeUserPoolResult == false)
            return false;
        DescribeUserPoolResult other = (DescribeUserPoolResult) obj;

        if (other.getUserPool() == null ^ this.getUserPool() == null)
            return false;
        if (other.getUserPool() != null && other.getUserPool().equals(this.getUserPool()) == false)
            return false;
        return true;
    }
}
